---
name: Bug report
about: Report a problem
title: ''
labels: bug
assignees: ''

---

A paragraph or two of the bug.

## Reproduction
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '...'
3. Scroll down to '...'
4. See error

## Expected behaviour
A clear and concise description of what you expected to happen.

## Actual behaviour
Include current behaviour and output.

## Environment
* `seddy`: version
* Python: version
* OS: Windows 10 / Ubuntu 18.04 / OSX
* `boto3`: version
